# Nautilus Librarian

[![CodeQL](https://github.com/Nautilus-Cyberneering/librarian/actions/workflows/codeql-analysis.yml/badge.svg)](https://github.com/Nautilus-Cyberneering/librarian/actions/workflows/codeql-analysis.yml)
[![Deploy Documentation](https://github.com/Nautilus-Cyberneering/librarian/actions/workflows/deploy-documentation.yml/badge.svg)](https://github.com/Nautilus-Cyberneering/librarian/actions/workflows/deploy-documentation.yml)
[![Lint Code Base](https://github.com/Nautilus-Cyberneering/librarian/actions/workflows/mega-linter.yml/badge.svg)](https://github.com/Nautilus-Cyberneering/librarian/actions/workflows/mega-linter.yml)
[![Publish Docker image](https://github.com/Nautilus-Cyberneering/librarian/actions/workflows/publish-docker-image.yml/badge.svg)](https://github.com/Nautilus-Cyberneering/librarian/actions/workflows/publish-docker-image.yml)
[![Publish GitHub Release](https://github.com/Nautilus-Cyberneering/librarian/actions/workflows/publish-github-release.yml/badge.svg)](https://github.com/Nautilus-Cyberneering/librarian/actions/workflows/publish-github-release.yml)
[![Publish package to PyPI](https://github.com/Nautilus-Cyberneering/librarian/actions/workflows/publish-pypi-package.yml/badge.svg)](https://github.com/Nautilus-Cyberneering/librarian/actions/workflows/publish-pypi-package.yml)
[![Test](https://github.com/Nautilus-Cyberneering/librarian/actions/workflows/test.yml/badge.svg)](https://github.com/Nautilus-Cyberneering/librarian/actions/workflows/test.yml)

A Python Console application to handle media libraries with [Git](https://git-scm.com/) and [Dvc](https://github.com/iterative/dvc).

Documentation: [https://nautilus-cyberneering.github.io/librarian/](https://nautilus-cyberneering.github.io/librarian/)

## Install

Requirements:

- Libvips
- Python 3.9

Install Python Package:

```shell
pip install nautilus-librarian
```

Please for a complete installation and development guide read the [documentation](https://nautilus-cyberneering.github.io/librarian/).
